<?php

declare(strict_types=1);

namespace Drupal\site_studio_webform_element\Controller;

use Drupal\Core\Cache\CacheableJsonResponse;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Site Studio Webform Element routes.
 */
final class WebformOptionListController implements ContainerInjectionInterface {

  /**
   * The controller constructor.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Return a list of Webform options.
   *
   * @return \Drupal\Core\Cache\CacheableJsonResponse
   *   The list of Webforms.
   */
  public function list() {
    $entities = $this->entityTypeManager->getStorage('webform')->loadMultiple();
    $webforms = [];

    foreach ($entities as $entity) {
      $webforms[] = [
        'label' => $entity->label(),
        'value' => $entity->id(),
      ];
    }

    return new CacheableJsonResponse($webforms);
  }

}
