<?php

namespace Drupal\site_studio_webform_element\Plugin\CustomElement;

use Drupal\cohesion_elements\CustomElementPluginBase;
use Drupal\Core\Render\Element\RenderCallbackInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\webform\Entity\Webform;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Site Studio element for embedding Webforms.
 *
 * @package Drupal\site_studio_webform_element\Plugin\CustomElement
 *
 * @CustomElement(
 *   id = "site_studio_webform_element",
 *   label = @Translation("Webform")
 * )
 */
class WebformElement extends CustomElementPluginBase implements RenderCallbackInterface {

  use StringTranslationTrait;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFields(): array {
    $webforms = $this->entityTypeManager->getStorage('webform')->loadMultiple();
    $forms = [];

    foreach ($webforms as $webform) {
      $forms[$webform->id()] = $webform->label();
    }

    return [
      'webform_id' => [
        'title' => 'Webform',
        'type' => 'select',
        'options' => $forms,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render($element_settings, $element_markup, $element_class): array {
    return [
      '#create_placeholder' => TRUE,
      '#lazy_builder' => [static::class . '::build', [$element_settings['webform_id']]],
    ];
  }

  /**
   * Lazy builder callback to build a Webform.
   *
   * @param string $webform_id
   *   The Webform id.
   *
   * @return array[]
   *   The render array.
   */
  public static function build(string $webform_id): array {
    return [
      'webform' => [
        '#type' => 'webform',
        '#webform' => Webform::load($webform_id),
      ],
    ];
  }

}
